pub struct AsyncDieselConnectionManager<C> { /* private fields */ }Available on crate feature
pool only.Expand description
Implementations
Sourceimpl<C> AsyncDieselConnectionManager<C>where
C: AsyncConnection + 'static,
impl<C> AsyncDieselConnectionManager<C>where
C: AsyncConnection + 'static,
Sourcepub fn new(connection_url: impl Into<String>) -> Selfwhere
C: AsyncConnection + 'static,
pub fn new(connection_url: impl Into<String>) -> Selfwhere
C: AsyncConnection + 'static,
Returns a new connection manager, which establishes connections to the given database URL.
Sourcepub fn new_with_config(
connection_url: impl Into<String>,
manager_config: ManagerConfig<C>,
) -> Self
pub fn new_with_config( connection_url: impl Into<String>, manager_config: ManagerConfig<C>, ) -> Self
Returns a new connection manager, which establishes connections with the given database URL and that uses the specified configuration