#[non_exhaustive]pub struct ManagerConfig<C> {
pub recycling_method: RecyclingMethod<C>,
pub custom_setup: SetupCallback<C>,
}Available on crate feature
pool only.Expand description
Configuration object for a Manager.
This makes it possible to specify which RecyclingMethod
should be used when retrieving existing objects from the Pool
and it allows to provide a custom setup function.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recycling_method: RecyclingMethod<C>Method of how a connection is recycled. See RecyclingMethod.
custom_setup: SetupCallback<C>Construct a new connection manger with a custom setup procedure
This can be used to for example establish a SSL secured postgres connection