Struct diesel_async::pg::TransactionBuilder
source · pub struct TransactionBuilder<'a, C> { /* private fields */ }postgres only.Expand description
Used to build a transaction, specifying additional details.
This struct is returned by AsyncPgConnection::build_transaction.
See the documentation for methods on this struct for usage examples.
See the PostgreSQL documentation for SET TRANSACTION
for details on the behavior of each option.
Implementations
sourceimpl<'a, C> TransactionBuilder<'a, C>where
C: AsyncConnection<Backend = Pg, TransactionManager = AnsiTransactionManager>,
impl<'a, C> TransactionBuilder<'a, C>where C: AsyncConnection<Backend = Pg, TransactionManager = AnsiTransactionManager>,
sourcepub fn read_only(self) -> Self
pub fn read_only(self) -> Self
Makes the transaction READ ONLY
Example
conn.build_transaction()
.read_only()
.run::<_, diesel::result::Error, _>(|conn| Box::pin(async move {
let read_attempt = users.select(name).load::<String>(conn).await;
assert!(read_attempt.is_ok());
let write_attempt = diesel::insert_into(users)
.values(name.eq("Ruby"))
.execute(conn)
.await;
assert!(write_attempt.is_err());
Ok(())
}) as _).await?;sourcepub fn read_write(self) -> Self
pub fn read_write(self) -> Self
Makes the transaction READ WRITE
This is the default, unless you’ve changed the
default_transaction_read_only configuration parameter.
Example
conn.build_transaction()
.read_write()
.run(|conn| Box::pin( async move {
let read_attempt = users.select(name).load::<String>(conn).await;
assert!(read_attempt.is_ok());
let write_attempt = diesel::insert_into(users)
.values(name.eq("Ruby"))
.execute(conn)
.await;
assert!(write_attempt.is_ok());
Ok(())
}) as _)
.awaitsourcepub fn deferrable(self) -> Self
pub fn deferrable(self) -> Self
Makes the transaction DEFERRABLE
Example
conn.build_transaction()
.deferrable()
.run(|conn| Box::pin(async { Ok(()) }))
.awaitsourcepub fn not_deferrable(self) -> Self
pub fn not_deferrable(self) -> Self
Makes the transaction NOT DEFERRABLE
This is the default, unless you’ve changed the
default_transaction_deferrable configuration parameter.
Example
conn.build_transaction()
.not_deferrable()
.run(|conn| Box::pin(async { Ok(()) }) as _)
.awaitsourcepub fn read_committed(self) -> Self
pub fn read_committed(self) -> Self
Makes the transaction ISOLATION LEVEL READ COMMITTED
This is the default, unless you’ve changed the
default_transaction_isolation_level configuration parameter.
Example
conn.build_transaction()
.read_committed()
.run(|conn| Box::pin(async { Ok(()) }) as _)
.awaitsourcepub fn repeatable_read(self) -> Self
pub fn repeatable_read(self) -> Self
Makes the transaction ISOLATION LEVEL REPEATABLE READ
Example
conn.build_transaction()
.repeatable_read()
.run(|conn| Box::pin(async { Ok(()) }) as _)
.awaitsourcepub fn serializable(self) -> Self
pub fn serializable(self) -> Self
Makes the transaction ISOLATION LEVEL SERIALIZABLE
Example
conn.build_transaction()
.serializable()
.run(|conn| Box::pin(async { Ok(()) }) as _)
.awaitsourcepub async fn run<'b, T, E, F>(&mut self, f: F) -> Result<T, E>where
F: for<'r> FnOnce(&'r mut C) -> ScopedBoxFuture<'b, 'r, Result<T, E>> + Send + 'a,
T: 'b,
E: From<Error> + 'b,
pub async fn run<'b, T, E, F>(&mut self, f: F) -> Result<T, E>where F: for<'r> FnOnce(&'r mut C) -> ScopedBoxFuture<'b, 'r, Result<T, E>> + Send + 'a, T: 'b, E: From<Error> + 'b,
Runs the given function inside of the transaction with the parameters given to this builder.
Returns an error if the connection is already inside a transaction, or if the transaction fails to commit or rollback
If the transaction fails to commit due to a SerializationFailure or a
ReadOnlyTransaction a rollback will be attempted. If the rollback succeeds,
the original error will be returned, otherwise the error generated by the rollback
will be returned. In the second case the connection should be considered broken
as it contains a uncommitted unabortable open transaction.